# Generated by ariadne-codegen on 2023-11-05 09:01
# Source: operations.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .fragments import SubscriptionFragment


class ApplySubscription(BaseModel):
    apply_subscription: "ApplySubscriptionApplySubscription" = Field(
        alias="applySubscription"
    )


class ApplySubscriptionApplySubscription(BaseModel):
    subscription: Optional["ApplySubscriptionApplySubscriptionSubscription"]


class ApplySubscriptionApplySubscriptionSubscription(SubscriptionFragment):
    pass


ApplySubscription.update_forward_refs()
ApplySubscriptionApplySubscription.update_forward_refs()
ApplySubscriptionApplySubscriptionSubscription.update_forward_refs()



# Generated by ariadne-codegen on 2023-11-05 09:01
# Source: operations.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class ReportEvent(BaseModel):
    report_event: Optional[str] = Field(alias="reportEvent")


ReportEvent.update_forward_refs()



# Generated by ariadne-codegen on 2023-11-05 09:01
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel


class ArchiveCustomer(BaseModel):
    archive_customer: "ArchiveCustomerArchiveCustomer" = Field(alias="archiveCustomer")


class ArchiveCustomerArchiveCustomer(BaseModel):
    customer_id: str = Field(alias="customerId")


ArchiveCustomer.update_forward_refs()
ArchiveCustomerArchiveCustomer.update_forward_refs()
